@@ -30,12 +30,12 @@ int main(int argc, char *argv[])
   Optionpk<string> output_opt("o", "output", "Output image file");
   Optionpk<string> dataType_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image","Byte");
   Optionpk<string> imageType_opt("of", "oformat", "image type string (see also gdal_translate)", "GTiff");
-  Optionpk<string> option_opt("co", "co", "options: NAME=VALUE [-co COMPRESS=LZW] [-co INTERLEAVE=BAND]");
+  Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<double> ulx_opt("ulx", "ulx", "Upper left x value bounding box (in geocoordinates if georef is true)", 0.0);
   Optionpk<double> uly_opt("uly", "uly", "Upper left y value bounding box (in geocoordinates if georef is true)", 0.0);
   Optionpk<double> dx_opt("dx", "dx", "Output resolution in x (in meter)");
   Optionpk<double> dy_opt("dy", "dy", "Output resolution in y (in meter)");
-  Optionpk<string> projection_opt("p", "projection", "projection string");
+  Optionpk<string> projection_opt("a_srs", "a_srs", "Override the projection for the output file");
   Optionpk<string> colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)");
   Optionpk<string> description_opt("d", "description", "Set image description");
   Optionpk<bool> verbose_opt("v", "verbose", "verbose", false);
