@@ -81,7 +81,7 @@ int main(int argc, char *argv[])
   Optionpk<unsigned short> flag_opt("f", "flag", "flag to put where image is invalid.", 0);
   Optionpk<string> output_opt("o", "output", "output classification image"); 
   Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image");
-  Optionpk<string> option_opt("co", "co", "options: NAME=VALUE [-co COMPRESS=LZW] [-co INTERLEAVE=BAND]");
+  Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<string> colorTable_opt("ct", "ct", "colour table in ascii format having 5 columns: id R G B ALFA (0: transparent, 255: solid)"); 
   Optionpk<string> prob_opt("prob", "prob", "probability image."); 
   Optionpk<string> entropy_opt("entropy", "entropy", "entropy image (measure for uncertainty of classifier output"); 
@@ -411,6 +411,15 @@ int main(int argc, char *argv[])
 	  cm.pushBackClassName(mapit->first,doSort);
 	++mapit;
       }
+      if(classname_opt.empty()){
+        std::cerr << "Warning: no class name and value pair provided for all " << nclass << " classes, using string2type<int> instead!" << std::endl;
+        for(int iclass=0;iclass<nclass;++iclass){
+          if(verbose_opt[0])
+            std::cout << iclass << " " << cm.getClass(iclass) << " -> " << string2type<short>(cm.getClass(iclass)) << std::endl;
+          classValueMap[cm.getClass(iclass)]=string2type<short>(cm.getClass(iclass));
+        }
+      }
+
       if(priors_opt.size()==nameVector.size()){
 	std::cerr << "Warning: please check if priors are provided in correct order!!!" << std::endl;
 	for(int iclass=0;iclass<nameVector.size();++iclass)
@@ -495,7 +504,7 @@ int main(int argc, char *argv[])
     if(verbose_opt[0])
       std::cout << "parameters ok, training" << std::endl;
     svm[ibag]=svm_train(&prob[ibag],&param[ibag]);
-    if(cv_opt[0]>0){
+    if(cv_opt[0]>1){
       double *target = Malloc(double,prob[ibag].l);
       svm_cross_validation(&prob[ibag],&param[ibag],cv_opt[0],target);
       assert(param[ibag].svm_type != EPSILON_SVR&&param[ibag].svm_type != NU_SVR);//only for regression
@@ -516,7 +525,7 @@ int main(int argc, char *argv[])
     // not free the memory used by svm_problem if you are still using the
     // svm_model produced by svm_train(). 
   }//for ibag
-  if(cv_opt[0]>0){
+  if(cv_opt[0]>1){
     assert(cm.nReference());
     std::cout << cm << std::endl;
     cout << "class #samples userAcc prodAcc" << endl;
@@ -527,13 +536,13 @@ int main(int argc, char *argv[])
     double dpa=0;
     double doa=0;
     for(short iclass=0;iclass<cm.nClasses();++iclass){
-      dua=cm.ua_pct(cm.getClass(iclass),&se95_ua);
-      dpa=cm.pa_pct(cm.getClass(iclass),&se95_pa);
+      dua=cm.ua(cm.getClass(iclass),&se95_ua);
+      dpa=cm.pa(cm.getClass(iclass),&se95_pa);
       cout << cm.getClass(iclass) << " " << cm.nReference(cm.getClass(iclass)) << " " << dua << " (" << se95_ua << ")" << " " << dpa << " (" << se95_pa << ")" << endl;
     }
     std::cout << "Kappa: " << cm.kappa() << std::endl;
-    doa=cm.oa_pct(&se95_oa);
-    std::cout << "Overall Accuracy: " << doa << " (" << se95_oa << ")"  << std::endl;
+    doa=cm.oa(&se95_oa);
+    std::cout << "Overall Accuracy: " << 100*doa << " (" << 100*se95_oa << ")"  << std::endl;
   }
 
   //--------------------------------- end of training -----------------------------------
@@ -548,14 +557,6 @@ int main(int argc, char *argv[])
     pfnProgress(progress,pszMessage,pProgressArg);
   //-------------------------------- open image file ------------------------------------
   if(input_opt[0].find(".shp")==string::npos){
-    if(classname_opt.empty()){
-      std::cerr << "Warning: no class name and value pair provided for all " << nclass << " classes, using string2type<int> instead!" << std::endl;
-      for(int iclass=0;iclass<nclass;++iclass){
-        if(verbose_opt[0])
-          std::cout << iclass << " " << cm.getClass(iclass) << " -> " << string2type<short>(cm.getClass(iclass)) << std::endl;
-	classValueMap[cm.getClass(iclass)]=string2type<short>(cm.getClass(iclass));
-      }
-    }
     ImgReaderGdal testImage;
     try{
       if(verbose_opt[0]>=1)
@@ -731,7 +732,6 @@ int main(int argc, char *argv[])
           exit(3);
         }
       }
-    
       //process per pixel
       for(int icol=0;icol<ncol;++icol){
         assert(hpixel[icol].size()==nband);
@@ -1031,14 +1031,14 @@ int main(int argc, char *argv[])
             switch(comb_opt[0]){
             default:
             case(0)://sum rule
-              probOut[iclass]+=result[iclass]+static_cast<float>(1.0-nbag)/nbag*priors[iclass];//add probabilities for each bag
-              break;
+              probOut[iclass]+=result[iclass]*priors[iclass];//add probabilities for each bag
+               break;
             case(1)://product rule
-              probOut[iclass]*=pow(priors[iclass],static_cast<float>(1.0-nbag)/nbag)*result[iclass];//add probabilities for each bag
+              probOut[iclass]*=pow(priors[iclass],static_cast<float>(1.0-nbag)/nbag)*result[iclass];//multiply probabilities for each bag
               break;
             case(2)://max rule
-              if(result[iclass]>probOut[iclass])
-                probOut[iclass]=result[iclass];
+              if(priors[iclass]*result[iclass]>probOut[iclass])
+                probOut[iclass]=priors[iclass]*result[iclass];
               break;
             }
           }
@@ -1118,8 +1118,8 @@ int main(int argc, char *argv[])
 	cout << cm.getClass(iclass) << " " << cm.nReference(cm.getClass(iclass)) << " " << dua << " (" << se95_ua << ")" << " " << dpa << " (" << se95_pa << ")" << endl;
       }
       std::cout << "Kappa: " << cm.kappa() << std::endl;
-      doa=cm.oa_pct(&se95_oa);
-      std::cout << "Overall Accuracy: " << doa << " (" << se95_oa << ")"  << std::endl;
+      doa=cm.oa(&se95_oa);
+      std::cout << "Overall Accuracy: " << 100*doa << " (" << 100*se95_oa << ")"  << std::endl;
     }
   }
   try{
