@@ -27,26 +27,29 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 
 int main(int argc, char *argv[])
 {
-  Optionpk<string> input_opt("i", "input", "Input image file.", "");
-  Optionpk<string> reference_opt("r", "reference", "Reference image file", "");
-  Optionpk<string> output_opt("o", "output", "Output image file. Default is empty: no output image, only report difference or identical.", "");
-  Optionpk<string> mask_opt("\0", "mask", "Mask image file. A single mask is supported only, but several mask values can be used. See also mflag option. (default is empty)", "");
-  Optionpk<string> colorTable_opt("\0", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)", "");
+  Optionpk<string> input_opt("i", "input", "Input image file.");
+  Optionpk<string> reference_opt("ref", "reference", "Reference image file");
+  Optionpk<string> output_opt("o", "output", "Output image file. Default is empty: no output image, only report difference or identical.");
+  Optionpk<string> mask_opt("m", "mask", "Mask image file. A single mask is supported only, but several mask values can be used. See also mflag option. (default is empty)");
+  Optionpk<string> colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)", "");
   Optionpk<short> valueE_opt("\0", "correct", "Value for correct pixels (0)", 0);
   Optionpk<short> valueO_opt("\0", "omission", "Value for omission errors: input label > reference label (default value is 1)", 1);
   Optionpk<short> valueC_opt("\0", "commission", "Value for commission errors: input label < reference label (default value is 2)", 2);
   Optionpk<short> flag_opt("f", "flag", "No value flag(s)", 0);
-  Optionpk<short> mflag_opt("m", "mflag", "Mask value(s) for invalid data (positive value), or for valid data (negative value). Default is 0", 0);
+  Optionpk<int> invalid_opt("t", "invalid", "Mask value(s) where image is invalid. Use negative value for valid data (example: use -t -1: if only -1 is valid value)", 0);
+  //  Optionpk<short> mflag_opt("t", "mflag", "Mask value(s) for invalid data (positive value), or for valid data (negative value). Default is 0", 0);
   Optionpk<short> band_opt("b", "band", "Band to extract (0)", 0);
   Optionpk<bool> confusion_opt("cm", "confusion", "create confusion matrix (to std out) (default value is 0)", false);
   Optionpk<short> lzw_opt("\0", "lzw", "compression (default value is 1)", 1);
   Optionpk<string> labelref_opt("lr", "lref", "name of the reference label in case reference is shape file(default is label)", "label");
   Optionpk<string> labelclass_opt("lc", "lclass", "name of the classified label in case output is shape file (default is class)", "class");
-  Optionpk<short> class_opt("c", "class", "numeric classes used (must cover range in input and reference raster image. Leave empty if range must be read from first input image (default)", 0);
+  // Optionpk<short> class_opt("c", "class", "numeric classes used (must cover range in input and reference raster image. Leave empty if range must be read from first input image (default)", 0);
   Optionpk<short> boundary_opt("\0", "boundary", "boundary for selecting the sample (default: 1)", 1);
   Optionpk<bool> disc_opt("\0", "circular", "use circular disc kernel boundary)", false);
   Optionpk<bool> homogeneous_opt("\0", "homogeneous", "only take homogeneous regions into account", false);
-  Optionpk<string> option_opt("co", "co", "options: NAME=VALUE [-co COMPRESS=LZW] [-co INTERLEAVE=BAND]");
+  Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
+  Optionpk<string> classname_opt("c", "class", "list of class names."); 
+  Optionpk<short> classvalue_opt("r", "reclass", "list of class values (use same order as in classname opt."); 
   Optionpk<short> verbose_opt("v", "verbose", "verbose (default value is 0)", 0);
 
   bool doProcess;//stop process when program was invoked with help option (-h --help)
@@ -61,16 +64,18 @@ int main(int argc, char *argv[])
     valueO_opt.retrieveOption(argc,argv);
     valueC_opt.retrieveOption(argc,argv);
     flag_opt.retrieveOption(argc,argv);
-    mflag_opt.retrieveOption(argc,argv);
+    invalid_opt.retrieveOption(argc,argv);
     band_opt.retrieveOption(argc,argv);
     confusion_opt.retrieveOption(argc,argv);
     lzw_opt.retrieveOption(argc,argv);
     labelref_opt.retrieveOption(argc,argv);
     labelclass_opt.retrieveOption(argc,argv);
-    class_opt.retrieveOption(argc,argv);
+    // class_opt.retrieveOption(argc,argv);
     boundary_opt.retrieveOption(argc,argv);
     disc_opt.retrieveOption(argc,argv);
     homogeneous_opt.retrieveOption(argc,argv);
+    classname_opt.retrieveOption(argc,argv);
+    classvalue_opt.retrieveOption(argc,argv);
     verbose_opt.retrieveOption(argc,argv);
   }
   catch(string predefinedString){
@@ -91,17 +96,25 @@ int main(int argc, char *argv[])
       cout << " " << flag_opt[iflag];
     cout << endl;
   }
-  if(mask_opt[0]!="")
-    assert(mask_opt.size()==input_opt.size());
+
+  assert(input_opt.size());
+  assert(reference_opt.size());
+  if(mask_opt.size())
+    while(mask_opt.size()<input_opt.size())
+      mask_opt.push_back(mask_opt[0]);
   vector<short> inputRange;
   vector<short> referenceRange;
   ConfusionMatrix cm;
   int nclass=0;
+  map<string,short> classValueMap;
+  vector<std::string> nameVector(255);//the inverse of the classValueMap
   vector<string> classNames;
   if(confusion_opt[0]){
-    if(class_opt.size()>1)
-      inputRange=class_opt;
-    else{
+    // if(class_opt.size()>1)
+    //   inputRange=class_opt;
+    // if(classvalue_opt.size()>1)
+    //   inputRange=classvalue_opt;
+    // else{
       try{
         if(verbose_opt[0])
           cout << "opening input image file " << input_opt[0] << endl;
@@ -113,7 +126,7 @@ int main(int argc, char *argv[])
       }
       inputReader.getRange(inputRange,band_opt[0]);
       inputReader.close();
-    }
+    // }
   
     for(int iflag=0;iflag<flag_opt.size();++iflag){
       vector<short>::iterator fit;
@@ -126,6 +139,15 @@ int main(int argc, char *argv[])
       cout << "nclass (inputRange.size()): " << nclass << endl;
       cout << "input range: " << endl;
     }
+    if(classname_opt.size()){
+      assert(classname_opt.size()==classvalue_opt.size());
+      for(int iclass=0;iclass<classname_opt.size();++iclass){
+        classValueMap[classname_opt[iclass]]=classvalue_opt[iclass];
+        assert(classvalue_opt[iclass]<nameVector.size());
+        nameVector[classvalue_opt[iclass]]=classname_opt[iclass];
+      }
+    }
+    // nclass=classValueMap.size();
     for(int rc=0;rc<inputRange.size();++rc){
       classNames.push_back(type2string(inputRange[rc]));
       if(verbose_opt[0])
@@ -138,6 +160,7 @@ int main(int argc, char *argv[])
         cout << iclass << " " << cm.getClass(iclass) << endl;
     }
   }
+
   unsigned int ntotalValidation=0;
   unsigned int nflagged=0;
   Vector2d<int> resultClass(nclass,nclass);
@@ -167,7 +190,7 @@ int main(int argc, char *argv[])
     pfnProgress(progress,pszMessage,pProgressArg);
   if(reference_opt[0].find(".shp")!=string::npos){
     for(int iinput=0;iinput<input_opt.size();++iinput){
-      if(output_opt[0]!="")
+      if(output_opt.size())
         assert(reference_opt.size()==output_opt.size());
       for(int iref=0;iref<reference_opt.size();++iref){
         if(verbose_opt[0])
@@ -176,7 +199,7 @@ int main(int argc, char *argv[])
         ImgReaderOgr referenceReader;
         try{
           inputReader.open(input_opt[iinput]);//,imagicX_opt[0],imagicY_opt[0]);
-          if(mask_opt[0]!=""){
+          if(mask_opt.size()){
             maskReader.open(mask_opt[iinput]);
             assert(inputReader.nrOfCol()==maskReader.nrOfCol());
             assert(inputReader.nrOfRow()==maskReader.nrOfRow());
@@ -192,7 +215,7 @@ int main(int argc, char *argv[])
 
         ImgWriterOgr ogrWriter;
         OGRLayer *writeLayer;
-        if(output_opt[0]!=""){
+        if(output_opt.size()){
           if(verbose_opt[0])
             cout << "creating output vector file " << output_opt[0] << endl;
           assert(output_opt[0].find(".shp")!=string::npos);
@@ -243,10 +266,24 @@ int main(int argc, char *argv[])
           //get x and y from readFeature
           double x,y;
           OGRGeometry *poGeometry;
+          OGRPolygon readPolygon;
+          OGRPoint centroidPoint;
+          OGRPoint *poPoint;
           poGeometry = readFeature->GetGeometryRef();
-          assert( poGeometry != NULL && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint );
-          OGRPoint *poPoint = (OGRPoint *) poGeometry;
-          //         writeFeature->SetGeometry(poPoint);
+          // assert( poGeometry != NULL && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint );
+          if(poGeometry==NULL)
+            continue;
+          else if(wkbFlatten(poGeometry->getGeometryType()) == wkbPolygon){
+            readPolygon = *((OGRPolygon *) poGeometry);
+            readPolygon.Centroid(&centroidPoint);
+            poPoint=&centroidPoint;
+          }
+          else if(wkbFlatten(poGeometry->getGeometryType()) == wkbPoint )
+            poPoint = (OGRPoint *) poGeometry;
+          else{
+            std::cerr << "Warning: skipping feature (not of type point or polygon)" << std::endl;
+            continue;
+          }
           x=poPoint->getX();
           y=poPoint->getY();
           short inputValue;
@@ -255,7 +292,14 @@ int main(int argc, char *argv[])
           short maskValue;
           short outputValue;
           //read referenceValue from feature
-          short referenceValue=readFeature->GetFieldAsInteger(readFeature->GetFieldIndex(labelref_opt[0].c_str()));
+          short referenceValue;
+          string referenceClassName;
+          if(classValueMap.size()){
+            referenceClassName=readFeature->GetFieldAsString(readFeature->GetFieldIndex(labelref_opt[0].c_str()));
+            referenceValue=classValueMap[referenceClassName];
+          }
+          else
+            referenceValue=readFeature->GetFieldAsInteger(readFeature->GetFieldIndex(labelref_opt[0].c_str()));
           if(verbose_opt[0])
             cout << "reference value: " << referenceValue << endl;
           bool pixelFlagged=false;
@@ -283,7 +327,7 @@ int main(int argc, char *argv[])
           if(static_cast<int>(i_centre)<0||static_cast<int>(i_centre)>=inputReader.nrOfCol())
             continue;
           OGRFeature *writeFeature;
-          if(output_opt[0]!=""){
+          if(output_opt.size()){
             writeFeature = OGRFeature::CreateFeature(writeLayer->GetLayerDefn());
             if(verbose_opt[0])
               cout << "copying fields from " << reference_opt[0] << endl;
@@ -320,18 +364,18 @@ int main(int argc, char *argv[])
                   break;
                 }
               }
-              maskFlagged=false;//(mflag_opt[ivalue]>=0)?false:true;
-              if(mask_opt[0]!=""){
+              maskFlagged=false;//(invalid_opt[ivalue]>=0)?false:true;
+              if(mask_opt.size()){
                 maskReader.readData(maskValue,GDT_Int16,i,j,band_opt[0]);
-                for(int ivalue=0;ivalue<mflag_opt.size();++ivalue){
-                  if(mflag_opt[ivalue]>=0){//values set in mflag_opt are invalid
-                    if(maskValue==mflag_opt[ivalue]){
+                for(int ivalue=0;ivalue<invalid_opt.size();++ivalue){
+                  if(invalid_opt[ivalue]>=0){//values set in invalid_opt are invalid
+                    if(maskValue==invalid_opt[ivalue]){
                       maskFlagged=true;
                       break;
                     }
                   }
-                  else{//only values set in mflag_opt are valid
-                    if(maskValue!=-mflag_opt[ivalue])
+                  else{//only values set in invalid_opt are valid
+                    if(maskValue!=-invalid_opt[ivalue])
                       maskFlagged=true;
                     else{
                       maskFlagged=false;
@@ -354,19 +398,26 @@ int main(int argc, char *argv[])
             //flag if not all pixels are homogeneous or if at least one pixel flagged
           
             if(!windowHasFlag&&isHomogeneous){
-              if(output_opt[0]!="")
+              if(output_opt.size())
                 writeFeature->SetField(labelclass_opt[0].c_str(),static_cast<int>(inputValue));
               if(confusion_opt[0]){
                 ++ntotalValidation;
-                int rc=distance(referenceRange.begin(),find(referenceRange.begin(),referenceRange.end(),referenceValue));
-                int ic=distance(inputRange.begin(),find(inputRange.begin(),inputRange.end(),inputValue));
-                assert(rc<nclass);
-                assert(ic<nclass);
-                ++nvalidation[rc];
-                ++resultClass[rc][ic];
-                if(verbose_opt[0]>1)
-                  cout << "increment: " << rc << " " << referenceRange[rc] << " " << ic << " " << inputRange[ic] << endl;
-                cm.incrementResult(cm.getClass(rc),cm.getClass(ic),1);
+                if(classValueMap.size()){
+                  assert(inputValue<nameVector.size());
+                  string className=nameVector[inputValue];
+                  cm.incrementResult(type2string<short>(classValueMap[referenceClassName]),type2string<short>(classValueMap[className]),1);
+                }
+                else{
+                  int rc=distance(referenceRange.begin(),find(referenceRange.begin(),referenceRange.end(),referenceValue));
+                  int ic=distance(inputRange.begin(),find(inputRange.begin(),inputRange.end(),inputValue));
+                  assert(rc<nclass);
+                  assert(ic<nclass);
+                  ++nvalidation[rc];
+                  ++resultClass[rc][ic];
+                  if(verbose_opt[0]>1)
+                    cout << "increment: " << rc << " " << referenceRange[rc] << " " << ic << " " << inputRange[ic] << endl;
+                  cm.incrementResult(cm.getClass(rc),cm.getClass(ic),1);
+                }
               }
               if(inputValue==referenceValue){//correct
                 if(valueE_opt[0]!=flag_opt[0])
@@ -399,24 +450,31 @@ int main(int argc, char *argv[])
                     fs << labelclass_opt[0] << "_" << windowJ << "_" << windowI;
                   else
                     fs << labelclass_opt[0];
-                  if(output_opt[0]!="")
+                  if(output_opt.size())
                     writeFeature->SetField(fs.str().c_str(),static_cast<int>(inputValue));
                   if(!windowJ&&!windowI){//centre pixel
                     if(confusion_opt[0]){
                       ++ntotalValidation;
-                      int rc=distance(referenceRange.begin(),find(referenceRange.begin(),referenceRange.end(),referenceValue));
-                      int ic=distance(inputRange.begin(),find(inputRange.begin(),inputRange.end(),inputValue));
-                      if(rc>=nclass)
-                        continue;
-                      if(ic>=nclass)
-                        continue;
-                      // assert(rc<nclass);
-                      // assert(ic<nclass);
-                      ++nvalidation[rc];
-                      ++resultClass[rc][ic];
-                      if(verbose_opt[0]>1)
-                        cout << "increment: " << rc << " " << referenceRange[rc] << " " << ic << " " << inputRange[ic] << endl;
-                      cm.incrementResult(cm.getClass(rc),cm.getClass(ic),1);
+                      if(classValueMap.size()){
+                        assert(inputValue<nameVector.size());
+                        string className=nameVector[inputValue];
+                        cm.incrementResult(type2string<short>(classValueMap[referenceClassName]),type2string<short>(classValueMap[className]),1);
+                      }
+                      else{
+                        int rc=distance(referenceRange.begin(),find(referenceRange.begin(),referenceRange.end(),referenceValue));
+                        int ic=distance(inputRange.begin(),find(inputRange.begin(),inputRange.end(),inputValue));
+                        if(rc>=nclass)
+                          continue;
+                        if(ic>=nclass)
+                          continue;
+                        // assert(rc<nclass);
+                        // assert(ic<nclass);
+                        ++nvalidation[rc];
+                        ++resultClass[rc][ic];
+                        if(verbose_opt[0]>1)
+                          cout << "increment: " << rc << " " << referenceRange[rc] << " " << ic << " " << inputRange[ic] << endl;
+                        cm.incrementResult(cm.getClass(rc),cm.getClass(ic),1);
+                      }
                     }
                     if(inputValue==referenceValue){//correct
                       if(valueE_opt[0]!=flag_opt[0])
@@ -433,7 +491,7 @@ int main(int argc, char *argv[])
               }
             }
           }
-          if(output_opt[0]!=""){
+          if(output_opt.size()){
             if(!windowAllFlagged){
               if(verbose_opt[0])
                 cout << "creating feature" << endl;
@@ -445,22 +503,22 @@ int main(int argc, char *argv[])
             OGRFeature::DestroyFeature( writeFeature );
           }
         }
-        if(output_opt[0]!="")
+        if(output_opt.size())
           ogrWriter.close();
         referenceReader.close();
         inputReader.close();
-        if(mask_opt[0]!="")
+        if(mask_opt.size())
           maskReader.close();
       }
     }
-  }
+  }//reference is shape file
   else{
     ImgWriterGdal imgWriter;
     try{
       inputReader.open(input_opt[0]);//,imagicX_opt[0],imagicY_opt[0]);
-      if(mask_opt[0]!="")
+      if(mask_opt.size())
         maskReader.open(mask_opt[0]);
-      if(output_opt[0]!=""){
+      if(output_opt.size()){
         if(verbose_opt[0])
           cout << "opening output image " << output_opt[0] << endl;
         string compression=(lzw_opt[0])? "LZW":"NONE";
@@ -494,7 +552,7 @@ int main(int argc, char *argv[])
     vector<short> lineInput(inputReader.nrOfCol());
     vector<short> lineMask(maskReader.nrOfCol());
     vector<short> lineOutput;
-    if(output_opt[0]!="")
+    if(output_opt.size())
       lineOutput.resize(inputReader.nrOfCol());
 
     int irow=0;
@@ -528,7 +586,7 @@ int main(int argc, char *argv[])
           cout << referenceRange[rc] << endl;
       }
       if(referenceRange.size()!=inputRange.size()){
-        if(confusion_opt[0]||output_opt[0]!=""){
+        if(confusion_opt[0]||output_opt.size()){
           cout << "reference range is not equal to input range!" << endl;
           cout << "Kappa: " << 0 << endl;    
           cout << "total weighted: " << 0 << endl;
@@ -542,8 +600,8 @@ int main(int argc, char *argv[])
     for(irow=0;irow<inputReader.nrOfRow()&&!isDifferent;++irow){
       //read line in lineInput, lineReference and lineMask
       inputReader.readData(lineInput,GDT_Int16,irow,band_opt[0]);
-      if(mask_opt[0]!="")
-        maskReader.readData(lineMask,GDT_Int16,irow,band_opt[0]);
+      if(mask_opt.size())
+        maskReader.readData(lineMask,GDT_Int16,irow);
       double x,y;//geo coordinates
       double ireference,jreference;//image coordinates in reference image
       for(icol=0;icol<inputReader.nrOfCol();++icol){
@@ -571,15 +629,15 @@ int main(int argc, char *argv[])
         bool flagged=false;
         for(int iflag=0;iflag<flag_opt.size();++iflag){
           if((lineInput[icol]==flag_opt[iflag])||(lineReference[ireference]==flag_opt[iflag])){
-            if(output_opt[0]!="")
+            if(output_opt.size())
               lineOutput[icol]=flag_opt[iflag];
             flagged=true;
             break;
           }
         }
-        if(mask_opt[0]!=""){
-          for(int ivalue=0;ivalue<mflag_opt.size();++ivalue){
-            if(lineMask[icol]==mflag_opt[ivalue]){
+        if(mask_opt.size()){
+          for(int ivalue=0;ivalue<invalid_opt.size();++ivalue){
+            if(lineMask[icol]==invalid_opt[ivalue]){
               flagged=true;
               break;
             }
@@ -599,7 +657,7 @@ int main(int argc, char *argv[])
             cm.incrementResult(cm.getClass(rc),cm.getClass(ic),1);
           }
           if(lineInput[icol]==lineReference[ireference]){//correct
-            if(output_opt[0]!=""){
+            if(output_opt.size()){
               if(valueE_opt[0]!=flag_opt[0])
                 lineOutput[icol]=valueE_opt[0];
               else
@@ -611,7 +669,7 @@ int main(int argc, char *argv[])
               isDifferent=true;
               break;
             }
-            if(output_opt[0]!=""){
+            if(output_opt.size()){
               if(lineInput[icol]<20){//forest
                 if(lineReference[icol]>=20)//gain
                   lineOutput[icol]=lineInput[icol]*10+1;//GAIN is 111,121,131
@@ -632,11 +690,11 @@ int main(int argc, char *argv[])
         }
         else{
           ++nflagged;
-          if(output_opt[0]!="")
+          if(output_opt.size())
             lineOutput[icol]=flag_opt[0];
         }
       }
-      if(output_opt[0]!=""){
+      if(output_opt.size()){
         try{
           imgWriter.writeData(lineOutput,GDT_Int16,irow);
         }
@@ -656,7 +714,7 @@ int main(int argc, char *argv[])
       if(!verbose_opt[0])
         pfnProgress(progress,pszMessage,pProgressArg);
     }
-    if(output_opt[0]!="")
+    if(output_opt.size())
       imgWriter.close();
     else if(!confusion_opt[0]){
       if(isDifferent)
@@ -666,7 +724,7 @@ int main(int argc, char *argv[])
     }
     referenceReader.close();
     inputReader.close();
-    if(mask_opt[0]!="")
+    if(mask_opt.size())
       maskReader.close();
   }
 
@@ -743,8 +801,8 @@ int main(int argc, char *argv[])
       dpa=cm.pa_pct(classNames[iclass],&se95_pa);
       cout << cm.getClass(iclass) << " " << cm.nReference(cm.getClass(iclass)) << " " << dua << " (" << se95_ua << ")" << " " << dpa << " (" << se95_pa << ")" << endl;
     }
-    doa=cm.oa_pct(&se95_oa);
+    doa=cm.oa(&se95_oa);
     cout << "Kappa: " << cm.kappa() << endl;
-    cout << "Overall Accuracy: " << doa << " (" << se95_oa << ")"  << endl;
+    cout << "Overall Accuracy: " << 100*doa << " (" << 100*se95_oa << ")"  << endl;
   }
 }
