@@ -154,7 +154,7 @@ double getCost(const vector<Vector2d<float> > &trainingFeatures)
     else if(cm.getClassIndex(type2string<short>(classValueMap[nameVector[iname]]))<0)
       cm.pushBackClassName(type2string<short>(classValueMap[nameVector[iname]]));
   }
-  if(cv_opt[0]>0){
+  if(cv_opt[0]>1){
     double *target = Malloc(double,prob.l);
     svm_cross_validation(&prob,&param,cv_opt[0],target);
     assert(param.svm_type != EPSILON_SVR&&param.svm_type != NU_SVR);//only for regression
@@ -563,7 +563,7 @@ int main(int argc, char *argv[])
       cost=getCost(trainingFeatures);
     }
     else{
-      while(cost-previousCost>epsilon_cost_opt[0]){
+      while(fabs(cost-previousCost)>epsilon_cost_opt[0]){
         previousCost=cost;
         switch(selMap[selector_opt[0]]){
         case(SFFS):
