@@ -38,7 +38,7 @@ int main(int argc, char *argv[])
 {
   Optionpk<string>  input_opt("i", "input", "Input image file(s). If input contains multiple images, a multi-band output is created", "");
   Optionpk<string>  output_opt("o", "output", "Output image file", "");
-  Optionpk<string>  projection_opt("p", "projection", "projection in EPSG format (leave blank to copy from input file, use EPSG:3035 to use European projection and to force to European grid", "");
+  Optionpk<string>  projection_opt("a_srs", "a_srs", "Override the projection for the output file (leave blank to copy from input file, use epsg:3035 to use European projection and force to European grid");
   Optionpk<string>  extent_opt("e", "extent", "get boundary from extent from polygons in vector file", "");
   Optionpk<double>  ulx_opt("ulx", "ulx", "Upper left x value bounding box (in geocoordinates if georef is true)", 0.0);
   Optionpk<double>  uly_opt("uly", "uly", "Upper left y value bounding box (in geocoordinates if georef is true)", 0.0);
@@ -50,10 +50,10 @@ int main(int argc, char *argv[])
   Optionpk<string>  otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image", "");
   Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image", "");
   Optionpk<string>  colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)", "");
-  Optionpk<string> option_opt("co", "co", "options: NAME=VALUE [-co COMPRESS=LZW] [-co INTERLEAVE=BAND]", "INTERLEAVE=BAND");
+  Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<short>  flag_opt("f", "flag", "Flag value to put in image if out of bounds.", 0);
   Optionpk<unsigned short>  resample_opt("r", "resample", "Resampling method (0: nearest neighbour, 1: bi-linear interpolation).", 0);
-  Optionpk<string>  description_opt("\0", "description", "Set image description", "");
+  Optionpk<string>  description_opt("\0", "description", "Set image description");
   Optionpk<string> mrule_opt("m", "mrule", "Mosaic rule for mosaic (overwrite, maxndvi, maxband, minband, validband, mean, maxvote (only for byte images), median, sum", "overwrite");
   Optionpk<int> ruleBand_opt("rb", "rband", "band index used for the rule (for ndvi, use --ruleBand=redBand --ruleBand=nirBand", 0);
   Optionpk<int> validBand_opt("vb", "validBand", "valid band index(es)", 0);
@@ -121,6 +121,10 @@ int main(int argc, char *argv[])
 
   while(invalid_opt.size()<validBand_opt.size())
     invalid_opt.push_back(invalid_opt[0]);
+  while(minValue_opt.size()<validBand_opt.size())
+    minValue_opt.push_back(minValue_opt[0]);
+  while(maxValue_opt.size()<validBand_opt.size())
+    maxValue_opt.push_back(maxValue_opt[0]);
   RESAMPLE theResample;
   switch(resample_opt[0]){
   case(BILINEAR):
@@ -195,7 +199,7 @@ int main(int argc, char *argv[])
     if(colorTable_opt[0]=="")
       if(imgReader.getColorTable())
         theColorTable=(imgReader.getColorTable()->Clone());
-    if(projection_opt[0]=="")
+    if(projection_opt.empty())
       theProjection=imgReader.getProjection();
     if(option_opt.findSubstring("INTERLEAVE=")==option_opt.end()){
       string theInterleave="INTERLEAVE=";
@@ -323,7 +327,10 @@ int main(int argc, char *argv[])
     minLRY=lry_opt[0];
   }
   
-  if(projection_opt[0].find("ETRS-LAEA")!=string::npos||projection_opt[0].find("EPSG:3035")!=string::npos||projection_opt[0].find("epsg:3035")!=string::npos){
+  bool forceEUgrid=false;
+  if(projection_opt.size())
+    forceEUgrid=(!(projection_opt[0].compare("EPSG:3035"))||!(projection_opt[0].compare("EPSG:3035"))||projection_opt[0].find("ETRS-LAEA")!=string::npos);
+  if(forceEUgrid){
     //force to LAEA grid
     minULX=floor(minULX);
     minULX-=static_cast<int>(minULX)%(static_cast<int>(dx));
@@ -373,10 +380,10 @@ int main(int argc, char *argv[])
   catch(string error){
     cout << error << endl;
   }
-  if(description_opt[0]!="")
+  if(description_opt.size())
     imgWriter.setImageDescription(description_opt[0]);
   imgWriter.setGeoTransform(minULX,maxULY,dx,dy,0,0);
-  if(projection_opt[0]!=""){
+  if(projection_opt.size()){
     if(verbose_opt[0])
       cout << "projection: " << projection_opt[0] << endl;
     imgWriter.setProjectionProj4(projection_opt[0]);
