@@ -31,89 +31,87 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include "base/Vector2d.h"
 #include "ImgReaderGdal.h"
 
-using namespace std;
-
 //--------------------------------------------------------------------------
 class ImgReaderOgr
 {
 public:
   ImgReaderOgr(void);
-  ImgReaderOgr(const string& filename);
+  ImgReaderOgr(const std::string& filename);
   ~ImgReaderOgr(void);
-  void open(const string& filename);
+  void open(const std::string& filename);
   void close(void);
-  //   int readData(Vector2d<double>& data, const OGRFieldType& fieldType, vector<string>& fields, int layer=0, bool pos=false);//default layer 0 and no pos information in data
-  template <typename T> int readXY(vector<T>& xVector, vector<T>& yVector, int layer=0, bool verbose=false);
-  template <typename T> int readY(vector<T>& yVector, int layer=0, bool verbose=false);
-  template <typename T> int readData(vector<T>& data, const OGRFieldType& fieldType, vector<string>& fields, OGRFeature *poFeature, int layer=0, bool pos=false, bool verbose=false);
-  template <typename T> int readData(vector<T>& data, const OGRFieldType& fieldType, const string& theField, int layer=0, bool verbose=false);
-  template <typename T> int readData(Vector2d<T>& data, const OGRFieldType& fieldType, vector<string>& fields, int layer=0, bool pos=false, bool verbose=false);//default layer 0 and no pos information in data
-  template <typename T> int readData(map<int,Vector2d<T> >& data, const OGRFieldType& fieldType, vector<string>& fields, const string& label, int layer=0, bool pos=false, bool verbose=false);//default layer 0 and no pos information in data
-  template <typename T> int readData(map<string,Vector2d<T> >& data, const OGRFieldType& fieldType, vector<string>& fields, const string& label, int layer=0, bool pos=false, bool verbose=false);//default layer 0 and no pos information in data
-  void shape2ascii(ostream& theOstream, const string& pointname, int layer=0, bool verbose=false);
+  //   int readData(Vector2d<double>& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, int layer=0, bool pos=false);//default layer 0 and no pos information in data
+  template <typename T> int readXY(std::vector<T>& xVector, std::vector<T>& yVector, int layer=0, bool verbose=false);
+  template <typename T> int readY(std::vector<T>& yVector, int layer=0, bool verbose=false);
+  template <typename T> int readData(std::vector<T>& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, OGRFeature *poFeature, int layer=0, bool pos=false, bool verbose=false);
+  template <typename T> int readData(std::vector<T>& data, const OGRFieldType& fieldType, const std::string& theField, int layer=0, bool verbose=false);
+  template <typename T> int readData(Vector2d<T>& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, int layer=0, bool pos=false, bool verbose=false);//default layer 0 and no pos information in data
+  template <typename T> int readData(std::map<int,Vector2d<T> >& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& label, int layer=0, bool pos=false, bool verbose=false);//default layer 0 and no pos information in data
+  template <typename T> int readData(std::map<std::string,Vector2d<T> >& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& label, int layer=0, bool pos=false, bool verbose=false);//default layer 0 and no pos information in data
+  void shape2ascii(std::ostream& theOstream, const std::string& pointname, int layer=0, bool verbose=false);
   unsigned long int getFeatureCount(int layer=0) const;
   int getFieldCount(int layer=0) const;
   OGRLayer* getLayer(int layer=0){return m_datasource->GetLayer(layer);};
-  string getProjection(int layer=0) const;
+  std::string getProjection(int layer=0) const;
   OGRwkbGeometryType getGeometryType(int layer=0) const;
-  string getLayerName(int layer=0){return m_datasource->GetLayer(layer)->GetLayerDefn()->GetName();};
+  std::string getLayerName(int layer=0){return m_datasource->GetLayer(layer)->GetLayerDefn()->GetName();};
   //  int getLayer(int layer=0) const;
-  int getFields(vector<string>& fields, int layer=0) const;
-  int getFields(vector<OGRFieldDefn*>& fields, int layer=0) const;
+  int getFields(std::vector<std::string>& fields, int layer=0) const;
+  int getFields(std::vector<OGRFieldDefn*>& fields, int layer=0) const;
   OGRDataSource* getDataSource(void) {return m_datasource;};
   OGRSFDriver* getDriver(void) const {return m_datasource->GetDriver();};
-//   OGRLayer *executeSql(const string& output,const string& sqlStatement, OGRGeometry* spatialFilter=NULL);
-  template<typename T> int readSql(Vector2d<T>& data, const OGRFieldType& fieldType, vector<string>& fields, const string& sqlStatement, OGRGeometry* spatialFilter=NULL, int layer=0, bool pos=false, bool verbose=false);
-  template<typename T> int readSql(map<int,Vector2d<T> >& data, const OGRFieldType& fieldType, vector<string>& fields, const string& label, const string& sqlStatement, OGRGeometry* spatialFilter, int layer=0, bool pos=false, bool verbose=false);
+//   OGRLayer *executeSql(const std::string& output,const std::string& sqlStatement, OGRGeometry* spatialFilter=NULL);
+  template<typename T> int readSql(Vector2d<T>& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& sqlStatement, OGRGeometry* spatialFilter=NULL, int layer=0, bool pos=false, bool verbose=false);
+  template<typename T> int readSql(std::map<int,Vector2d<T> >& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& label, const std::string& sqlStatement, OGRGeometry* spatialFilter, int layer=0, bool pos=false, bool verbose=false);
   bool getExtent(double& ulx, double& uly, double& lrx, double& lry, int layer=0);
 
-  friend ostream& operator<<(ostream& theOstream, ImgReaderOgr& theImageReader);
+  friend std::ostream& operator<<(std::ostream& theOstream, ImgReaderOgr& theImageReader);
   
 protected:
   void setCodec(void);
 
-  string m_filename;
+  std::string m_filename;
   OGRDataSource *m_datasource;
 };
 
 //read data from all features in a map, organized by classes
-template <typename T> int ImgReaderOgr::readData(map<int,Vector2d<T> >& data, const OGRFieldType& fieldType, vector<string>& fields, const string& label, int layer, bool pos, bool verbose)
+template <typename T> int ImgReaderOgr::readData(std::map<int,Vector2d<T> >& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& label, int layer, bool pos, bool verbose)
 {
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
   assert(m_datasource->GetLayerCount()>layer);
   OGRLayer  *poLayer;
   if(verbose)
-    cout << "number of layers: " << m_datasource->GetLayerCount() << endl;
+    std::cout << "number of layers: " << m_datasource->GetLayerCount() << std::endl;
   poLayer = m_datasource->GetLayer(layer);
   if(poLayer!=NULL){
     OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
     if(fields.empty()){
       fields.resize(poFDefn->GetFieldCount());
       if(verbose)
-        cout << "resized fields to " << fields.size() << endl;
+        std::cout << "resized fields to " << fields.size() << std::endl;
     }
     //start reading features from the layer
     OGRFeature *poFeature;
     if(verbose)
-      cout << "reset reading" << endl;
+      std::cout << "reset reading" << std::endl;
     poLayer->ResetReading();
     unsigned long int ifeature=0;
     int posOffset=(pos)?2:0;
     if(verbose)
-      cout << "going through features" << endl << flush;
+      std::cout << "going through features" << std::endl << std::flush;
     int theClass=0;
     while( (poFeature = poLayer->GetNextFeature()) != NULL ){
-      vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
+      std::vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
       if(verbose)
-        cout << "reading feature " << ifeature << endl << flush;
+        std::cout << "reading feature " << ifeature << std::endl << std::flush;
       OGRGeometry *poGeometry;
       poGeometry = poFeature->GetGeometryRef();
       if(verbose){
         if(poGeometry == NULL)
-          cerr << "no geometry defined" << endl << flush;
+          std::cerr << "no geometry defined" << std::endl << std::flush;
         else if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-          cerr << "Warning: poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl << flush;
+          std::cerr << "Warning: poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl << std::flush;
       }
       assert(poGeometry != NULL );
              // && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -140,10 +138,10 @@ template <typename T> int ImgReaderOgr::readData(map<int,Vector2d<T> >& data, co
         }       
       }
       // OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
-      string featurename;
+      std::string featurename;
       for(int iField=0;iField<poFDefn->GetFieldCount();++iField){
         OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
-        string fieldname=poFieldDefn->GetNameRef();
+        std::string fieldname=poFieldDefn->GetNameRef();
         if(fieldname==label)
           theClass=poFeature->GetFieldAsInteger(iField);
         else{
@@ -170,7 +168,7 @@ template <typename T> int ImgReaderOgr::readData(map<int,Vector2d<T> >& data, co
             break;
           default:
             {
-              string errorstring="field type not supported in ImgReaderOgr::ReadData";
+              std::string errorstring="field type not supported in ImgReaderOgr::ReadData";
               throw(errorstring);
             }
             break;
@@ -182,14 +180,14 @@ template <typename T> int ImgReaderOgr::readData(map<int,Vector2d<T> >& data, co
       ++ifeature;
     }
     if(verbose)
-      cout << "number of features read: " << ifeature << endl << flush;
-    typename map<int,Vector2d<T> >::const_iterator mit=data.begin();
+      std::cout << "number of features read: " << ifeature << std::endl << std::flush;
+    typename std::map<int,Vector2d<T> >::const_iterator mit=data.begin();
     int nband=0;
     if(verbose)
-      cout << "read classes: " << flush;
+      std::cout << "read classes: " << std::flush;
     while(mit!=data.end()){
       if(verbose)
-        cout << mit->first << " " << flush;
+        std::cout << mit->first << " " << std::flush;
       if(!nband)
         nband=fields.size();
       if(pos)
@@ -199,25 +197,25 @@ template <typename T> int ImgReaderOgr::readData(map<int,Vector2d<T> >& data, co
       ++mit;
     }
     if(verbose)
-      cout << endl << flush;
+      std::cout << std::endl << std::flush;
     return(nband);
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
 }
 
 //read data from all features in a map, organized by class names
-template <typename T> int ImgReaderOgr::readData(map<string,Vector2d<T> >& data, const OGRFieldType& fieldType, vector<string>& fields, const string& label, int layer, bool pos, bool verbose)
+template <typename T> int ImgReaderOgr::readData(std::map<std::string,Vector2d<T> >& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& label, int layer, bool pos, bool verbose)
 {
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
   assert(m_datasource->GetLayerCount()>layer);
   OGRLayer  *poLayer;
   if(verbose)
-    cout << "number of layers: " << m_datasource->GetLayerCount() << endl;
+    std::cout << "number of layers: " << m_datasource->GetLayerCount() << std::endl;
   poLayer = m_datasource->GetLayer(layer);
   if(poLayer!=NULL){
     OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
@@ -226,30 +224,30 @@ template <typename T> int ImgReaderOgr::readData(map<string,Vector2d<T> >& data,
     if(fields.empty()){
       fields.resize(poFDefn->GetFieldCount());
       if(verbose)
-        cout << "resized fields to " << fields.size() << endl;
+        std::cout << "resized fields to " << fields.size() << std::endl;
     }
 
     //start reading features from the layer
     OGRFeature *poFeature;
     if(verbose)
-      cout << "reset reading" << endl;
+      std::cout << "reset reading" << std::endl;
     poLayer->ResetReading();
     unsigned long int ifeature=0;
     int posOffset=(pos)?2:0;
     if(verbose)
-      cout << "going through features to fill in string map" << endl << flush;
-    string theClass;
+      std::cout << "going through features to fill in string map" << std::endl << std::flush;
+    std::string theClass;
     while( (poFeature = poLayer->GetNextFeature()) != NULL ){
-      vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
+      std::vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
       if(verbose)
-        cout << "reading feature " << ifeature << endl << flush;
+        std::cout << "reading feature " << ifeature << std::endl << std::flush;
       OGRGeometry *poGeometry;
       poGeometry = poFeature->GetGeometryRef();
       if(verbose){
         if(poGeometry == NULL)
-          cerr << "no geometry defined" << endl << flush;
+          std::cerr << "no geometry defined" << std::endl << std::flush;
         else if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-          cerr << "Warning: poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl << flush;
+          std::cerr << "Warning: poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl << std::flush;
       }
       assert(poGeometry != NULL );
              // && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -275,10 +273,10 @@ template <typename T> int ImgReaderOgr::readData(map<string,Vector2d<T> >& data,
         }       
       }
       // OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();//got LayerDefn already...
-      string featurename;
+      std::string featurename;
       for(int iField=0;iField<poFDefn->GetFieldCount();++iField){
         OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
-        string fieldname=poFieldDefn->GetNameRef();
+        std::string fieldname=poFieldDefn->GetNameRef();
         if(fieldname==label){
           theClass=poFeature->GetFieldAsString(iField);
           if(verbose)
@@ -308,7 +306,7 @@ template <typename T> int ImgReaderOgr::readData(map<string,Vector2d<T> >& data,
             break;
           default:
             {
-              string errorstring="field type not supported in ImgReaderOgr::ReadData";
+              std::string errorstring="field type not supported in ImgReaderOgr::ReadData";
               throw(errorstring);
             }
             break;
@@ -320,14 +318,14 @@ template <typename T> int ImgReaderOgr::readData(map<string,Vector2d<T> >& data,
       ++ifeature;
     }
     if(verbose)
-      cout << "number of features read: " << ifeature << endl << flush;
-    typename map<string,Vector2d<T> >::const_iterator mit=data.begin();
+      std::cout << "number of features read: " << ifeature << std::endl << std::flush;
+    typename std::map<std::string,Vector2d<T> >::const_iterator mit=data.begin();
     int nband=0;
     if(verbose)
-      cout << "read classes: " << flush;
+      std::cout << "read classes: " << std::flush;
     while(mit!=data.end()){
       if(verbose)
-        cout << mit->first << " " << flush;
+        std::cout << mit->first << " " << std::flush;
       if(!nband)
         nband=fields.size();
       if(pos)
@@ -337,44 +335,44 @@ template <typename T> int ImgReaderOgr::readData(map<string,Vector2d<T> >& data,
       ++mit;
     }
     if(verbose)
-      cout << endl << flush;
+      std::cout << std::endl << std::flush;
     return(nband);
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
 }
 
 //read x positions
-template <typename T> int ImgReaderOgr::readXY(vector<T>& xVector, vector<T>& yVector, int layer, bool verbose){
+template <typename T> int ImgReaderOgr::readXY(std::vector<T>& xVector, std::vector<T>& yVector, int layer, bool verbose){
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
   assert(m_datasource->GetLayerCount()>layer);
   OGRLayer  *poLayer;
   if(verbose)
-    cout << "number of layers: " << m_datasource->GetLayerCount() << endl;
+    std::cout << "number of layers: " << m_datasource->GetLayerCount() << std::endl;
   poLayer = m_datasource->GetLayer(layer);
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   //start reading features from the layer
   OGRFeature *poFeature;
   if(verbose)
-    cout << "reset reading" << endl;
+    std::cout << "reset reading" << std::endl;
   poLayer->ResetReading();
   unsigned long int ifeature=0;
   if(verbose)
-    cout << "going through features" << endl << flush;
+    std::cout << "going through features" << std::endl << std::flush;
   while( (poFeature = poLayer->GetNextFeature()) != NULL ){
     if(verbose)
-      cout << "reading feature " << ifeature << endl << flush;
+      std::cout << "reading feature " << ifeature << std::endl << std::flush;
     OGRGeometry *poGeometry;
     poGeometry = poFeature->GetGeometryRef();
     if(verbose){
       if(poGeometry == NULL)
-        cerr << "no geometry defined" << endl << flush;
+        std::cerr << "no geometry defined" << std::endl << std::flush;
       else// if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-        cout << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl;
+        std::cout << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl;
     }
     // assert(poGeometry != NULL 
     //        && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -388,35 +386,35 @@ template <typename T> int ImgReaderOgr::readXY(vector<T>& xVector, vector<T>& yV
     return xVector.size();
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
 }
 
 //read data from a single feature
-template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRFieldType& fieldType, vector<string>& fields, OGRFeature *poFeature, int layer, bool pos, bool verbose)
+template <typename T> int ImgReaderOgr::readData(std::vector<T>& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, OGRFeature *poFeature, int layer, bool pos, bool verbose)
 {
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
   assert(m_datasource->GetLayerCount()>layer);
   OGRLayer  *poLayer;
   if(verbose)
-    cout << "number of layers: " << m_datasource->GetLayerCount() << endl;
+    std::cout << "number of layers: " << m_datasource->GetLayerCount() << std::endl;
   poLayer = m_datasource->GetLayer(layer);
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   if(fields.empty()){
     fields.resize(poFDefn->GetFieldCount());
     if(verbose)
-      cout << "resized fields to " << fields.size() << endl;
+      std::cout << "resized fields to " << fields.size() << std::endl;
   }
   OGRGeometry *poGeometry;
   poGeometry = poFeature->GetGeometryRef();
   if(verbose){
     if(poGeometry == NULL)
-      cerr << "no geometry defined" << endl << flush;
+      std::cerr << "no geometry defined" << std::endl << std::flush;
     else if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-      cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl << flush;
+      std::cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl << std::flush;
   }
   assert(poGeometry != NULL);
          // && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -443,10 +441,10 @@ template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRField
     }       
 
   }
-  string featurename;
+  std::string featurename;
   for(int iField=0;iField<poFDefn->GetFieldCount();++iField){
     OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
-    string fieldname=poFieldDefn->GetNameRef();
+    std::string fieldname=poFieldDefn->GetNameRef();
     switch(fieldType){
     case(OFTReal):
       if(fields.size()<poFDefn->GetFieldCount()){
@@ -470,7 +468,7 @@ template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRField
       break;
     default:
       {
-        string errorstring="field type not supported in ImgReaderOgr::ReadData";
+        std::string errorstring="field type not supported in ImgReaderOgr::ReadData";
         throw(errorstring);
       }
       break;
@@ -485,50 +483,50 @@ template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRField
     return fields.size();
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
 }
 
 //read one field from all features
-template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRFieldType& fieldType, const string& theField, int layer, bool verbose)
+template <typename T> int ImgReaderOgr::readData(std::vector<T>& data, const OGRFieldType& fieldType, const std::string& theField, int layer, bool verbose)
 {
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
   assert(m_datasource->GetLayerCount()>layer);
   OGRLayer  *poLayer;
   if(verbose)
-    cout << "number of layers: " << m_datasource->GetLayerCount() << endl;
+    std::cout << "number of layers: " << m_datasource->GetLayerCount() << std::endl;
   poLayer = m_datasource->GetLayer(layer);
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   int nfield=(theField!="")? poFDefn->GetFieldCount() : 1;
   if(theField==""){
     //read first field available 
     if(verbose)
-      cout << "read first field from total of " << nfield << endl;
+      std::cout << "read first field from total of " << nfield << std::endl;
   }
 
   //start reading features from the layer
   OGRFeature *poFeature;
   if(verbose)
-    cout << "reset reading" << endl;
+    std::cout << "reset reading" << std::endl;
   poLayer->ResetReading();
   unsigned long int ifeature=0;
   if(verbose)
-    cout << "going through features" << endl << flush;
+    std::cout << "going through features" << std::endl << std::flush;
   while( (poFeature = poLayer->GetNextFeature()) != NULL ){
-    // vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
+    // std::vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
     T theFeature;
     if(verbose)
-      cout << "reading feature " << ifeature << endl << flush;
+      std::cout << "reading feature " << ifeature << std::endl << std::flush;
     OGRGeometry *poGeometry;
     poGeometry = poFeature->GetGeometryRef();
     if(verbose){
       if(poGeometry == NULL)
-        cerr << "no geometry defined" << endl << flush;
+        std::cerr << "no geometry defined" << std::endl << std::flush;
       else// if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-        cout << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl;
+        std::cout << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl;
     }
     // assert(poGeometry != NULL 
     //        && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -536,7 +534,7 @@ template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRField
 
     for(int iField=0;iField<nfield;++iField){
       OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
-      string fieldname=poFieldDefn->GetNameRef();
+      std::string fieldname=poFieldDefn->GetNameRef();
       if(fieldname!=theField)
         continue;
       switch(fieldType){
@@ -546,7 +544,7 @@ template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRField
       break;
       default:
         {
-          string errorstring="field type not supported in ImgReaderOgr::ReadData";
+          std::string errorstring="field type not supported in ImgReaderOgr::ReadData";
           throw(errorstring);
         }
         break;
@@ -554,55 +552,55 @@ template <typename T> int ImgReaderOgr::readData(vector<T>& data, const OGRField
     }
     data.push_back(theFeature);
     if(verbose)
-      cout << "feature is: " << theFeature << endl;
+      std::cout << "feature is: " << theFeature << std::endl;
     ++ifeature;
   }
   if(data.size()){
     return data.size();
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
 }
 
 //read data from all features  
-template <typename T> int ImgReaderOgr::readData(Vector2d<T>& data, const OGRFieldType& fieldType, vector<string>& fields, int layer, bool pos, bool verbose)
+template <typename T> int ImgReaderOgr::readData(Vector2d<T>& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, int layer, bool pos, bool verbose)
 {
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
   assert(m_datasource->GetLayerCount()>layer);
   OGRLayer  *poLayer;
   if(verbose)
-    cout << "number of layers: " << m_datasource->GetLayerCount() << endl;
+    std::cout << "number of layers: " << m_datasource->GetLayerCount() << std::endl;
   poLayer = m_datasource->GetLayer(layer);
   OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
   if(fields.empty()){
     fields.resize(poFDefn->GetFieldCount());
     if(verbose)
-      cout << "resized fields to " << fields.size() << endl;
+      std::cout << "resized fields to " << fields.size() << std::endl;
   }
   //start reading features from the layer
   OGRFeature *poFeature;
   if(verbose)
-    cout << "reset reading" << endl;
+    std::cout << "reset reading" << std::endl;
   poLayer->ResetReading();
   unsigned long int ifeature=0;
   int posOffset=(pos)?2:0;
   if(verbose)
-    cout << "going through features" << endl << flush;
+    std::cout << "going through features" << std::endl << std::flush;
   while( (poFeature = poLayer->GetNextFeature()) != NULL ){
-    vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
+    std::vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
     if(verbose)
-      cout << "reading feature " << ifeature << endl << flush;
+      std::cout << "reading feature " << ifeature << std::endl << std::flush;
     OGRGeometry *poGeometry;
     poGeometry = poFeature->GetGeometryRef();
     if(verbose){
       if(poGeometry == NULL)
-        cerr << "no geometry defined" << endl << flush;
+        std::cerr << "no geometry defined" << std::endl << std::flush;
       else if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-        cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl << flush;
+        std::cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl << std::flush;
     }
     assert(poGeometry != NULL 
            && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -612,10 +610,10 @@ template <typename T> int ImgReaderOgr::readData(Vector2d<T>& data, const OGRFie
       theFeature.push_back(poPoint->getY());
     }
     OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
-    string featurename;
+    std::string featurename;
     for(int iField=0;iField<poFDefn->GetFieldCount();++iField){
       OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
-      string fieldname=poFieldDefn->GetNameRef();
+      std::string fieldname=poFieldDefn->GetNameRef();
       switch(fieldType){
       case(OFTReal):
         if(fields.size()<poFDefn->GetFieldCount()){
@@ -639,7 +637,7 @@ template <typename T> int ImgReaderOgr::readData(Vector2d<T>& data, const OGRFie
         break;
       default:
         {
-          string errorstring="field type not supported in ImgReaderOgr::ReadData";
+          std::string errorstring="field type not supported in ImgReaderOgr::ReadData";
           throw(errorstring);
         }
         break;
@@ -657,13 +655,13 @@ template <typename T> int ImgReaderOgr::readData(Vector2d<T>& data, const OGRFie
     return fields.size();
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
 }
 
-template<typename T> int ImgReaderOgr::readSql(map<int, Vector2d<T> >& data, const OGRFieldType& fieldType, vector<string>& fields, const string& label, const string& sqlStatement, OGRGeometry* spatialFilter, int layer, bool pos, bool verbose)
+template<typename T> int ImgReaderOgr::readSql(std::map<int, Vector2d<T> >& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& label, const std::string& sqlStatement, OGRGeometry* spatialFilter, int layer, bool pos, bool verbose)
 {
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
@@ -675,29 +673,29 @@ template<typename T> int ImgReaderOgr::readSql(map<int, Vector2d<T> >& data, con
     if(fields.empty()){
       fields.resize(poFDefn->GetFieldCount());
       if(verbose)
-        cout << "resized fields to " << fields.size() << endl;
+        std::cout << "resized fields to " << fields.size() << std::endl;
     }
     //start reading features from the layer
     OGRFeature *poFeature;
     if(verbose)
-      cout << "reset reading" << endl;
+      std::cout << "reset reading" << std::endl;
     poLayer->ResetReading();
     unsigned long int ifeature=0;
     int posOffset=(pos)?2:0;
     if(verbose)
-      cout << "going through features" << endl << flush;
+      std::cout << "going through features" << std::endl << std::flush;
     int theClass=0;
     while( (poFeature = poLayer->GetNextFeature()) != NULL ){
-      vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
+      std::vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
       if(verbose)
-        cout << "reading feature " << ifeature << endl << flush;
+        std::cout << "reading feature " << ifeature << std::endl << std::flush;
       OGRGeometry *poGeometry;
       poGeometry = poFeature->GetGeometryRef();
       if(verbose){
         if(poGeometry == NULL)
-          cerr << "no geometry defined" << endl << flush;
+          std::cerr << "no geometry defined" << std::endl << std::flush;
         else if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-          cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl << flush;
+          std::cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl << std::flush;
       }
       assert(poGeometry != NULL 
              && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -707,10 +705,10 @@ template<typename T> int ImgReaderOgr::readSql(map<int, Vector2d<T> >& data, con
         theFeature.push_back(poPoint->getY());
       }
       OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
-      string featurename;
+      std::string featurename;
       for(int iField=0;iField<poFDefn->GetFieldCount();++iField){
         OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
-        string fieldname=poFieldDefn->GetNameRef();
+        std::string fieldname=poFieldDefn->GetNameRef();
         if(fieldname==label)
           theClass=poFeature->GetFieldAsInteger(iField);
         else{
@@ -737,7 +735,7 @@ template<typename T> int ImgReaderOgr::readSql(map<int, Vector2d<T> >& data, con
             break;
           default:
             {
-              string errorstring="field type not supported in ImgReaderOgr::ReadData";
+              std::string errorstring="field type not supported in ImgReaderOgr::ReadData";
               throw(errorstring);
             }
             break;
@@ -748,14 +746,14 @@ template<typename T> int ImgReaderOgr::readSql(map<int, Vector2d<T> >& data, con
       ++ifeature;
     }
     if(verbose)
-      cout << "number of features read: " << ifeature << endl << flush;
-    typename map<int,Vector2d<T> >::const_iterator mit=data.begin();
+      std::cout << "number of features read: " << ifeature << std::endl << std::flush;
+    typename std::map<int,Vector2d<T> >::const_iterator mit=data.begin();
     int nband=0;
     if(verbose)
-      cout << "read classes: " << flush;
+      std::cout << "read classes: " << std::flush;
     while(mit!=data.end()){
       if(verbose)
-        cout << mit->first << " " << flush;
+        std::cout << mit->first << " " << std::flush;
       if(!nband)
         nband=fields.size();
       if(pos)
@@ -765,17 +763,17 @@ template<typename T> int ImgReaderOgr::readSql(map<int, Vector2d<T> >& data, con
       ++mit;
     }
     if(verbose)
-      cout << endl << flush;
+      std::cout << std::endl << std::flush;
     return(nband);
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
 }
 
-template<typename T> int ImgReaderOgr::readSql(Vector2d<T>& data, const OGRFieldType& fieldType, vector<string>& fields, const string& sqlStatement, OGRGeometry* spatialFilter, int layer, bool pos, bool verbose)
+template<typename T> int ImgReaderOgr::readSql(Vector2d<T>& data, const OGRFieldType& fieldType, std::vector<std::string>& fields, const std::string& sqlStatement, OGRGeometry* spatialFilter, int layer, bool pos, bool verbose)
 {
   if(layer<0)
     layer=m_datasource->GetLayerCount()-1;
@@ -787,28 +785,28 @@ template<typename T> int ImgReaderOgr::readSql(Vector2d<T>& data, const OGRField
     if(fields.empty()){
       fields.resize(poFDefn->GetFieldCount());
       if(verbose)
-        cout << "resized fields to " << fields.size() << endl;
+        std::cout << "resized fields to " << fields.size() << std::endl;
     }
     //start reading features from the layer
     OGRFeature *poFeature;
     if(verbose)
-      cout << "reset reading" << endl;
+      std::cout << "reset reading" << std::endl;
     poLayer->ResetReading();
     unsigned long int ifeature=0;
     int posOffset=(pos)?2:0;
     if(verbose)
-      cout << "going through features" << endl << flush;
+      std::cout << "going through features" << std::endl << std::flush;
     while( (poFeature = poLayer->GetNextFeature()) != NULL ){
-      vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
+      std::vector<T> theFeature;//(fields.size()+posOffset);//x,y+selectedfields
       if(verbose)
-        cout << "reading feature " << ifeature << endl << flush;
+        std::cout << "reading feature " << ifeature << std::endl << std::flush;
       OGRGeometry *poGeometry;
       poGeometry = poFeature->GetGeometryRef();
       if(verbose){
         if(poGeometry == NULL)
-          cerr << "no geometry defined" << endl << flush;
+          std::cerr << "no geometry defined" << std::endl << std::flush;
         else if(wkbFlatten(poGeometry->getGeometryType()) != wkbPoint)
-          cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << endl << flush;
+          std::cerr << "poGeometry type: " << wkbFlatten(poGeometry->getGeometryType()) << std::endl << std::flush;
       }
       assert(poGeometry != NULL 
              && wkbFlatten(poGeometry->getGeometryType()) == wkbPoint);
@@ -818,10 +816,10 @@ template<typename T> int ImgReaderOgr::readSql(Vector2d<T>& data, const OGRField
         theFeature.push_back(poPoint->getY());
       }
       OGRFeatureDefn *poFDefn = poLayer->GetLayerDefn();
-      string featurename;
+      std::string featurename;
       for(int iField=0;iField<poFDefn->GetFieldCount();++iField){
         OGRFieldDefn *poFieldDefn = poFDefn->GetFieldDefn(iField);
-        string fieldname=poFieldDefn->GetNameRef();
+        std::string fieldname=poFieldDefn->GetNameRef();
         switch(fieldType){
         case(OFTReal):
           if(fields.size()<poFDefn->GetFieldCount()){
@@ -845,7 +843,7 @@ template<typename T> int ImgReaderOgr::readSql(Vector2d<T>& data, const OGRField
           break;
         default:
           {
-            string errorstring="field type not supported in ImgReaderOgr::ReadData";
+            std::string errorstring="field type not supported in ImgReaderOgr::ReadData";
             throw(errorstring);
           }
           break;
@@ -867,7 +865,7 @@ template<typename T> int ImgReaderOgr::readSql(Vector2d<T>& data, const OGRField
       return(0);
   }
   else{
-    ostringstream ess;
+    std::ostringstream ess;
     ess << "no layer in " << m_filename;
     throw(ess.str());
   }
